@@ -8,6 +8,7 @@ import os
 import sys
 from logging import getLogger
 from os.path import isdir, isfile, join
+from pathlib import Path
 
 # create support
 from conda.base.constants import ChannelPriority, DepsModifier, UpdateModifier
@@ -18,7 +19,7 @@ from conda.cli.common import (
     ensure_name_or_prefix,
     specs_from_url,
 )
-from conda.cli.install import check_prefix, clone, get_revision, print_activate
+from conda.cli.install import check_prefix, clone, get_revision
 from conda.cli.main import generate_parser, init_loggers
 from conda.common.compat import on_win
 from conda.common.path import paths_equal
@@ -49,7 +50,13 @@ import mamba
 from mamba import repoquery as repoquery_api
 from mamba.linking import handle_txn
 from mamba.mamba_shell_init import shell_init
-from mamba.utils import get_installed_jsonfile, init_api_context, load_channels, to_txn
+from mamba.utils import (
+    get_installed_jsonfile,
+    init_api_context,
+    load_channels,
+    print_activate,
+    to_txn,
+)
 
 if sys.version_info < (3, 2):
     sys.stdout = codecs.lookup("utf-8")[-1](sys.stdout)
@@ -217,10 +224,12 @@ def remove(args, parser):
             return exit_code
 
         package_cache = api.MultiPackageCache(context.pkgs_dirs)
-        transaction = api.Transaction(solver, package_cache)
-        downloaded = transaction.prompt(repos)
-        if not downloaded:
+        transaction = api.Transaction(solver, package_cache, repos)
+
+        if not transaction.prompt():
             exit(0)
+        elif not context.dry_run:
+            transaction.fetch_extract_packages()
 
         mmb_specs, to_link, to_unlink = transaction.to_conda()
         transaction.log_json()
@@ -482,6 +491,7 @@ def install(args, parser, command="install"):
         to_link = []
         to_unlink = []
         installed_pkg_recs = []
+        transaction = None
     else:
         index = load_channels(pool, channels, repos)
 
@@ -552,23 +562,31 @@ def install(args, parser, command="install"):
             return exit_code
 
         package_cache = api.MultiPackageCache(context.pkgs_dirs)
-        transaction = api.Transaction(solver, package_cache)
+        transaction = api.Transaction(solver, package_cache, repos)
         mmb_specs, to_link, to_unlink = transaction.to_conda()
 
         specs_to_add = [MatchSpec(m) for m in mmb_specs[0]]
         specs_to_remove = [MatchSpec(m) for m in mmb_specs[1]]
 
         transaction.log_json()
-        downloaded = transaction.prompt(repos)
-        if not downloaded:
-            exit(0)
 
-    # if use_mamba_experimental and not os.name == "nt":
-    if use_mamba_experimental:
-        if newenv and not isdir(context.target_prefix) and not context.dry_run:
-            mkdir_p(prefix)
-        transaction.execute(prefix_data)
+    if use_mamba_experimental and transaction is not None:
+        if transaction.prompt():
+            if (
+                newenv
+                and not isdir(Path(prefix) / "conda-meta")
+                and not context.dry_run
+            ):
+                mkdir_p(Path(prefix) / "conda-meta")
+
+            transaction.execute(prefix_data)
     else:
+        if transaction is not None:
+            if transaction.prompt() is False:
+                exit(0)
+            if not context.dry_run:
+                transaction.fetch_extract_packages()
+
         conda_transaction = to_txn(
             specs_to_add,
             specs_to_remove,
@@ -745,7 +763,7 @@ def do_call(args, parser):
     else:
         print(
             "Currently, only install, create, list, search, run,"
-            " info and clean are supported through mamba."
+            " info, clean, activate and deactivate are supported through mamba."
         )
 
         return 0
@@ -757,7 +775,10 @@ def configure_clean_locks(sub_parsers):
         g.title: g for g in sub_parsers.choices["clean"]._action_groups
     }["Removal Targets"]
     removal_target_options.add_argument(
-        "-l", "--locks", action="store_true", help="Remove lock files.",
+        "-l",
+        "--locks",
+        action="store_true",
+        help="Remove lock files.",
     )
 
 
@@ -884,9 +905,11 @@ def main(*args, **kwargs):
     init_std_stream_encoding()
 
     if "activate" in sys.argv or "deactivate" in sys.argv:
-        print("Run 'mamba init' to be able to run mamba activate/deactivate")
-        print("and start a new shell session. Or use conda to activate/deactivate.")
-        print("\n    $ conda " + " ".join(sys.argv[1:]) + "\n")
+        print(
+            "Run 'mamba init' to be able to run mamba activate/deactivate\n"
+            "and start a new shell session. Or use conda to activate/deactivate.\n",
+            file=sys.stderr,
+        )
         return sys.exit(-1)
 
     if not args:
